@@ -224,7 +224,6 @@ epub_document_links_has_document_links(EvDocumentLinks *document_links)
     return TRUE;
 }
 
-
 typedef struct _LinksCBStruct {
     GtkTreeModel *model;
     GtkTreeIter  *parent;
@@ -413,7 +412,6 @@ epub_remove_temporary_dir (gchar *path_name)
     return (g_remove (path_name));
 }
 
-
 static gboolean
 check_mime_type             (const gchar* uri,
                              GError** error);
@@ -637,7 +635,7 @@ check_mime_type(const gchar* uri,GError** error)
         for (i = 0; i < g_strv_length (mimetypes); i++) {
            if (strcmp(mimeFromFile, mimetypes[i]) == 0)
                 return TRUE;
-	}
+        }
 
         /* fallback for malformed epub files */
         if (strcmp (mimeFromFile, "application/zip") == 0)
@@ -673,7 +671,7 @@ check_mime_type(const gchar* uri,GError** error)
 }
 
 static gboolean
-extract_one_file(EpubDocument* epub_document,GError ** error)
+extract_one_file(EpubDocument* epub_document, GFile *tmp_gfile, GError ** error)
 {
     GFile * outfile ;
     gsize writesize = 0;
@@ -700,6 +698,20 @@ extract_one_file(EpubDocument* epub_document,GError ** error)
     gfilepath = g_string_new(epub_document->tmp_archive_dir) ;
     g_string_append_printf(gfilepath,"/%s",(gchar*)currentfilename);
 
+    outfile = g_file_new_for_path (gfilepath->str);
+    g_autofree gchar *rpath = g_file_get_relative_path (tmp_gfile, outfile);
+
+    if (rpath == NULL)
+    {
+        g_set_error_literal (error,
+                             EV_DOCUMENT_ERROR,
+                             EV_DOCUMENT_ERROR_INVALID,
+                             _("epub file is invalid or corrupt"));
+        g_critical ("Invalid filename in Epub container - '%s'", (gchar *) currentfilename);
+        result = FALSE;
+        goto out;
+    }
+
     /*if we encounter a directory, make a directory inside our temporary folder.*/
     if (directory != NULL && *directory == '\0')
     {
@@ -727,7 +739,6 @@ extract_one_file(EpubDocument* epub_document,GError ** error)
         g_string_free(dir_create,TRUE);
     }
 
-    outfile = g_file_new_for_path(gfilepath->str);
     outstream = g_file_create(outfile,G_FILE_CREATE_PRIVATE,NULL,error);
     gpointer buffer = g_malloc0(512);
     while ( (writesize = unzReadCurrentFile(epub_document->epubDocument,buffer,512) ) != 0 )
@@ -740,10 +751,10 @@ extract_one_file(EpubDocument* epub_document,GError ** error)
     }
     g_free(buffer);
     g_output_stream_close((GOutputStream*)outstream,NULL,error);
-    g_object_unref(outfile) ;
-    g_object_unref(outstream) ;
+    g_object_unref(outstream);
 
 out:
+    g_object_unref(outfile);
     unzCloseCurrentFile (epub_document->epubDocument) ;
     g_string_free(gfilepath,TRUE);
     g_free(currentfilename);
@@ -755,6 +766,7 @@ extract_epub_from_container (const gchar* uri,
                              EpubDocument *epub_document,
                              GError ** error)
 {
+    GFile *tmp_gfile = NULL;
     GError *err = NULL;
     epub_document->archivename = g_filename_from_uri(uri,NULL,error);
 
@@ -816,9 +828,10 @@ extract_epub_from_container (const gchar* uri,
         goto out;
     }
 
+    tmp_gfile = g_file_new_for_path (epub_document->tmp_archive_dir);
     while ( TRUE )
     {
-        if ( extract_one_file(epub_document,&err) == FALSE )
+        if ( extract_one_file(epub_document, tmp_gfile, &err) == FALSE )
         {
             if (err) {
                 g_propagate_error (error, err);
@@ -839,6 +852,7 @@ extract_epub_from_container (const gchar* uri,
     }
 
 out:
+    g_clear_object (&tmp_gfile);
     unzClose(epub_document->epubDocument);
     return result;
 }
@@ -1562,7 +1576,6 @@ epub_document_check_add_night_sheet(EvDocument *document)
 
         gchar *csspath = g_strdup_printf("%s/atrilnightstyle.css",epub_document->documentdir);
 
-
         GFile *styles = g_file_new_for_path (csspath);
         GOutputStream *outstream = (GOutputStream*)g_file_create(styles,G_FILE_CREATE_PRIVATE,NULL,NULL);
         if ( g_output_stream_write((GOutputStream*)outstream,style,strlen(style),NULL,NULL) == -1 )
@@ -1636,7 +1649,6 @@ epub_document_set_index_pages(GList *index,GList *contentList)
     g_list_foreach(index,(GFunc)page_set_function,contentList);
 }
 
-
 static void
 add_mathjax_script_node_to_file(gchar *filename, gchar *data)
 {
@@ -1784,7 +1796,6 @@ epub_document_init (EpubDocument *epub_document)
     epub_document->docTitle = NULL;
 }
 
-
 static void
 epub_document_finalize (GObject *object)
 {
@@ -1826,7 +1837,6 @@ epub_document_finalize (GObject *object)
     G_OBJECT_CLASS (epub_document_parent_class)->finalize (object);
 }
 
-
 static void
 epub_document_class_init (EpubDocumentClass *klass)
 {
