@@ -25,15 +25,12 @@
 
 #include "ev-message-area.h"
 
-#define EV_MESSAGE_AREA_GET_PRIVATE(obj) \
-	(G_TYPE_INSTANCE_GET_PRIVATE ((obj), EV_TYPE_MESSAGE_AREA, EvMessageAreaPrivate))
-
 struct _EvMessageAreaPrivate {
 	GtkWidget *main_box;
 	GtkWidget *image;
 	GtkWidget *label;
 	GtkWidget *secondary_label;
-	
+
 	guint      message_type : 3;
 };
 
@@ -53,7 +50,7 @@ static void ev_message_area_get_property (GObject      *object,
 					  GValue       *value,
 					  GParamSpec   *pspec);
 
-G_DEFINE_TYPE (EvMessageArea, ev_message_area, GTK_TYPE_INFO_BAR)
+G_DEFINE_TYPE_WITH_PRIVATE (EvMessageArea, ev_message_area, GTK_TYPE_INFO_BAR)
 
 static void
 ev_message_area_class_init (EvMessageAreaClass *class)
@@ -84,8 +81,6 @@ ev_message_area_class_init (EvMessageAreaClass *class)
 							      "The image",
 							      GTK_TYPE_WIDGET,
 							      G_PARAM_READWRITE));
-
-	g_type_class_add_private (gobject_class, sizeof (EvMessageAreaPrivate));
 }
 
 static void
@@ -94,7 +89,7 @@ ev_message_area_init (EvMessageArea *area)
 	GtkWidget *hbox, *vbox;
 	GtkWidget *content_area;
 
-	area->priv = EV_MESSAGE_AREA_GET_PRIVATE (area);
+	area->priv = ev_message_area_get_instance_private (area);
 
 	area->priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
 
@@ -305,7 +300,7 @@ ev_message_area_set_image_from_stock (EvMessageArea *area,
 {
 	g_return_if_fail (EV_IS_MESSAGE_AREA (area));
 	g_return_if_fail (icon_name != NULL);
-	
+
 	gtk_image_set_from_icon_name (GTK_IMAGE (area->priv->image),
 				  icon_name,
 				  GTK_ICON_SIZE_DIALOG);
